<?php
#
# Ces fichiers sont a placer dans le repertoire base/ de votre plugin
#
/**
 * Gestion de l'importation de `spip_subdivisions_apis`
**/

/**
 * Fonction d'import de la table `spip_subdivisions_apis`
 * à utiliser dans le fichier d'administration du plugin
 *
 *     ```
 *     include_spip('base/importer_spip_subdivisions_apis');
 *     $maj['create'][] = array('importer_spip_subdivisions_apis');
 *     ```
 *
**/
function importer_spip_subdivisions_apis() {
	######## VERIFIEZ LE NOM DE LA TABLE D'INSERTION ###########
	$table = 'spip_subdivisions_apis';

	// nom_du_champ_source => nom_du_champ_destination
	// mettre vide la destination ou supprimer la ligne permet de ne pas importer la colonne.
	$correspondances = array(
		//"id_subdivision_api" => "id_subdivision_api",
		"iso_moi" => "iso_moi",
		"titre" => "titre",
		"dataset" => "dataset",
		"noeud" => "noeud",
		"api" => "api",
		"q" => "q",
		"iso_lang" => "iso_lang",
		"rows" => "rows",
		"start" => "start",
		"sort" => "sort",
		"facet" => "facet",
		"refine" => "refine",
		"exclude" => "exclude",
		"geofilter_distance" => "geofilter_distance",
		"geofilter_polygon" => "geofilter_polygon",
		"timezone" => "timezone",
		"relation" => "relation",
		"mention" => "mention",
		"lien" => "lien",
		'date' => 'date',
		'statut' => 'statut',
		'maj' => 'maj'
	);

	// transposer les donnees dans la nouvelle structure
	$inserts = array();
	list($cles, $valeurs) = donnees_spip_subdivisions_apis();
	// on remet les noms des cles dans le tableau de valeur
	// en s'assurant de leur correspondance au passage
	if (is_array($valeurs)) {
		foreach ($valeurs as $v) {
			$i = array();
			foreach ($v as $k => $valeur) {
				$cle = $cles[$k];
				if (isset($correspondances[$cle]) and $correspondances[$cle]) {
					$i[ $correspondances[$cle] ] = $valeur;
				}
			}
			$inserts[] = $i;
		}
		unset($valeurs);

		// inserer les donnees en base.
		$nb_inseres = 0;
		// ne pas reimporter ceux deja la (en cas de timeout)
		$nb_deja_la = sql_countsel($table);
		$inserts = array_slice($inserts, $nb_deja_la);
		$nb_a_inserer = count($inserts);
		// on decoupe en petit bout (pour reprise sur timeout)
		$inserts = array_chunk($inserts, 100);
		foreach ($inserts as $i) {
			sql_insertq_multi($table, $i);
			$nb_inseres += count($i);
			// serie_alter() relancera la fonction jusqu'a ce que l'on sorte sans timeout.
			if (time() >= _TIME_OUT) {
				// on ecrit un gentil message pour suivre l'avancement.
				echo "<br />Insertion dans $table relanc&eacute;e : ";
				echo "<br />- $nb_deja_la &eacute;taient d&eacute;j&agrave; l&agrave;";
				echo "<br />- $nb_inseres ont &eacute;t&eacute; ins&eacute;r&eacute;s.";
				$a_faire = $nb_a_inserer - $nb_inseres;
				echo "<br />- $a_faire &agrave; faire.";
				return;
			}
		}
	}
}


/**
 * Donnees de la table spip_subdivisions_apis
**/
function donnees_spip_subdivisions_apis() {

	$cles = array(
		"id_subdivision_api",
		"iso_moi",
		"titre",
		"dataset",
		"noeud",
		"api",
		"q",
		"iso_lang",
		"rows",
		"start",
		"sort",
		"facet",
		"refine",
		"exclude",
		"geofilter_distance",
		"geofilter_polygon",
		"timezone",
		"relation",
		"mention",
		"lien",
		'date',
		'statut',
		'maj');


	$valeurs = array(
		array(
			"1",
			"FR-GUA",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"01",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"2",
			"FR-MTQ",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"02",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"3",
			"FR-GUF",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"03",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"4",
			"FR-LRE",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"04",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"5",
			"FR-MAY",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"06",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"6",
			"FR-IDF",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"11",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"7",
			"FR-CVL",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"24",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"8",
			"FR-BFC",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"27",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"9",
			"FR-NOR",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"28",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"10",
			"FR-HDF",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"32",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"11",
			"FR-GES",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"44",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"12",
			"FR-PDL",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"52",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"13",
			"FR-BRE",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"53",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"14",
			"FR-NAQ",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"75",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"15",
			"FR-OCC",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"76",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"16",
			"FR-ARA",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"84",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"17",
			"FR-PAC",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"93",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"18",
			"FR-COR",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-regions-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_insee",
			"94",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"19",
			"FR-18",
			"Plateforme ouverte des données publiques du Conseil Régional Centre-Val de Loire et de ses partenaires.",
			"contours-geographiques-des-departements-2019",
			"records/0/fields/geo_shape",
			"https://data.centrevaldeloire.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"nom_dep0",
			"CHER",
			"",
			"",
			"",
			"",
			"definition",
			"source : data.centrevaldeloire.fr",
			"https://data.centrevaldeloire.fr/explore/dataset/contours-geographiques-des-departements-2019/information/",
			"2019-01-01 00:00:00",
			"publie",
			""),
		array(
			"20",
			"FR-28",
			"Plateforme ouverte des données publiques du Conseil Régional Centre-Val de Loire et de ses partenaires.",
			"contours-geographiques-des-departements-2019",
			"records/0/fields/geo_shape",
			"https://data.centrevaldeloire.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"nom_dep0",
			"EURE-ET-LOIR",
			"",
			"",
			"",
			"",
			"definition",
			"source : data.centrevaldeloire.fr",
			"https://data.centrevaldeloire.fr/explore/dataset/contours-geographiques-des-departements-2019/information/",
			"2019-01-01 00:00:00",
			"publie",
			""),
		array(
			"21",
			"FR-36",
			"Plateforme ouverte des données publiques du Conseil Régional Centre-Val de Loire et de ses partenaires.",
			"contours-geographiques-des-departements-2019",
			"records/0/fields/geo_shape",
			"https://data.centrevaldeloire.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"nom_dep0",
			"INDRE",
			"",
			"",
			"",
			"",
			"definition",
			"source : data.centrevaldeloire.fr",
			"https://data.centrevaldeloire.fr/explore/dataset/contours-geographiques-des-departements-2019/information/",
			"2019-01-01 00:00:00",
			"publie",
			""),
		array(
			"22",
			"FR-37",
			"Plateforme ouverte des données publiques du Conseil Régional Centre-Val de Loire et de ses partenaires.",
			"contours-geographiques-des-departements-2019",
			"records/0/fields/geo_shape",
			"https://data.centrevaldeloire.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"nom_dep0",
			"INDRE-ET-LOIRE",
			"",
			"",
			"",
			"",
			"definition",
			"source : data.centrevaldeloire.fr",
			"https://data.centrevaldeloire.fr/explore/dataset/contours-geographiques-des-departements-2019/information/",
			"2019-01-01 00:00:00",
			"publie",
			""),
		array(
			"23",
			"FR-41",
			"Plateforme ouverte des données publiques du Conseil Régional Centre-Val de Loire et de ses partenaires.",
			"contours-geographiques-des-departements-2019",
			"records/0/fields/geo_shape",
			"https://data.centrevaldeloire.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"nom_dep0",
			"LOIR-ET-CHER",
			"",
			"",
			"",
			"",
			"definition",
			"source : data.centrevaldeloire.fr",
			"https://data.centrevaldeloire.fr/explore/dataset/contours-geographiques-des-departements-2019/information/",
			"2019-01-01 00:00:00",
			"publie",
			""),
		array(
			"24",
			"FR-45",
			"Plateforme ouverte des données publiques du Conseil Régional Centre-Val de Loire et de ses partenaires.",
			"contours-geographiques-des-departements-2019",
			"records/0/fields/geo_shape",
			"https://data.centrevaldeloire.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"nom_dep0",
			"LOIRET",
			"",
			"",
			"",
			"",
			"definition",
			"source : data.centrevaldeloire.fr",
			"https://data.centrevaldeloire.fr/explore/dataset/contours-geographiques-des-departements-2019/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"25",
			"FR-75",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"75",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"26",
			"FR-92",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"92",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"27",
			"FR-95",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"95",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"28",
			"FR-93",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"93",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"29",
			"FR-94",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"94",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"30",
			"FR-91",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"91",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"31",
			"FR-78",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"78",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"32",
			"FR-77",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"77",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"33",
			"FR-01",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"01",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"34",
			"FR-02",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"02",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"35",
			"FR-03",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"03",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"36",
			"FR-04",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"04",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"37",
			"FR-05",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"05",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"38",
			"FR-06",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"06",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"39",
			"FR-07",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"07",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"40",
			"FR-08",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"08",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"41",
			"FR-09",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"09",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"42",
			"FR-10",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"10",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"43",
			"FR-11",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"11",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"44",
			"FR-12",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"12",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"45",
			"FR-13",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"13",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"46",
			"FR-14",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"14",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"47",
			"FR-15",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"15",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"48",
			"FR-16",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"16",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"49",
			"FR-17",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"17",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"50",
			"FR-19",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"19",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"52",
			"FR-21",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"21",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"53",
			"FR-22",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"22",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"54",
			"FR-23",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"23",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"55",
			"FR-24",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"24",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"56",
			"FR-25",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"25",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"57",
			"FR-26",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"26",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"58",
			"FR-27",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"27",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"59",
			"FR-29",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"29",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"60",
			"FR-30",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"30",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"61",
			"FR-31",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"31",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"62",
			"FR-32",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"32",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"63",
			"FR-33",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"33",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"64",
			"FR-34",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"34",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"65",
			"FR-35",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"35",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"66",
			"FR-38",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"38",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"67",
			"FR-39",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"39",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"68",
			"FR-40",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"40",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"69",
			"FR-42",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"42",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"70",
			"FR-43",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"43",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"71",
			"FR-44",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"44",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"72",
			"FR-46",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"46",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"73",
			"FR-47",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"47",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"74",
			"FR-48",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"48",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"75",
			"FR-49",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"49",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"76",
			"FR-50",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"50",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"77",
			"FR-51",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"51",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"78",
			"FR-52",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"52",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"79",
			"FR-53",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"53",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"80",
			"FR-54",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"54",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"81",
			"FR-55",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"55",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"82",
			"FR-56",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"56",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"83",
			"FR-57",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"57",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"84",
			"FR-58",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"58",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"85",
			"FR-59",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"59",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"86",
			"FR-60",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"60",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"87",
			"FR-61",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"61",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"88",
			"FR-62",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"62",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"89",
			"FR-63",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"63",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"90",
			"FR-64",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"64",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"91",
			"FR-65",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"65",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"92",
			"FR-66",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"66",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"93",
			"FR-67",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"67",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"94",
			"FR-68",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"68",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"95",
			"FR-69",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"69",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"96",
			"FR-70",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"70",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"97",
			"FR-2A",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"2A",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"98",
			"FR-2B",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"2B",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"99",
			"FR-71",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"71",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"100",
			"FR-72",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"72",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"101",
			"FR-73",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"73",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"102",
			"FR-74",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"74",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"103",
			"FR-76",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"76",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"104",
			"FR-80",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"80",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"105",
			"FR-79",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"79",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"106",
			"FR-81",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"81",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"107",
			"FR-82",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"82",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"108",
			"FR-83",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"83",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"109",
			"FR-84",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"84",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"110",
			"FR-85",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"85",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"111",
			"FR-86",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"86",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"112",
			"FR-87",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"87",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"113",
			"FR-88",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"88",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"114",
			"FR-89",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"89",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			''),
		array(
			"115",
			"FR-90",
			"Plateforme ouverte des données publiques de l'URSSAF.",
			"contours-geographiques-des-departements-2016",
			"records/0/fields/geo_shape",
			"https://open.urssaf.fr/api/records/1.0/search/",
			"",
			"",
			"1",
			"",
			"",
			"code_departement",
			"90",
			"",
			"",
			"",
			"",
			"definition",
			"source : open.urssaf.fr",
			"https://open.urssaf.fr/explore/dataset/contours-geographiques-des-departements-2016/information/",
			"2019-01-01 00:00:00",
			"publie",
			'')			
	);


	return array($cles, $valeurs);
}